@@ -341,10 +341,14 @@ class PreviewUpdateGameServerClusterResponse(proto.Message):
 
 class GameServerClusterConnectionInfo(proto.Message):
     r"""The game server cluster connection information.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         gke_cluster_reference (google.cloud.gaming_v1.types.GkeClusterReference):
             Reference to the GKE cluster where the game
             servers are installed.
+            This field is a member of `oneof`_ ``cluster_reference``.
         namespace (str):
             Namespace designated on the game server
             cluster where the Agones game server instances
@@ -363,6 +367,7 @@ class GameServerClusterConnectionInfo(proto.Message):
 
 class GkeClusterReference(proto.Message):
     r"""A reference to a GKE cluster.
+
     Attributes:
         cluster (str):
             The full or partial name of a GKE cluster, using one of the
@@ -381,6 +386,7 @@ class GkeClusterReference(proto.Message):
 
 class GameServerCluster(proto.Message):
     r"""A game server cluster resource.
+
     Attributes:
         name (str):
             Required. The resource name of the game server cluster, in
@@ -425,6 +431,7 @@ class GameServerCluster(proto.Message):
 
 class KubernetesClusterState(proto.Message):
     r"""The state of the Kubernetes cluster.
+
     Attributes:
         agones_version_installed (str):
             Output only. The version of Agones currently
