@@ -266,6 +266,7 @@ class FetchDeploymentStateResponse(proto.Message):
 
 class GameServerDeployment(proto.Message):
     r"""A game server deployment resource.
+
     Attributes:
         name (str):
             The resource name of the game server deployment, in the
@@ -297,11 +298,16 @@ class GameServerDeployment(proto.Message):
 
 class GameServerConfigOverride(proto.Message):
     r"""A game server config override.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         realms_selector (google.cloud.gaming_v1.types.RealmSelector):
             Selector for choosing applicable realms.
+            This field is a member of `oneof`_ ``selector``.
         config_version (str):
             The game server config for this override.
+            This field is a member of `oneof`_ ``change``.
     """
 
     realms_selector = proto.Field(
@@ -350,6 +356,7 @@ class GameServerDeploymentRollout(proto.Message):
 
 class PreviewGameServerDeploymentRolloutRequest(proto.Message):
     r"""Request message for PreviewGameServerDeploymentRollout.
+
     Attributes:
         rollout (google.cloud.gaming_v1.types.GameServerDeploymentRollout):
             Required. The game server deployment rollout to be updated.
