@@ -30,6 +30,8 @@ from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.gaming_v1beta.services.game_server_clusters_service import pagers
@@ -356,10 +358,7 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
-                always_use_jwt_access=(
-                    Transport == type(self).get_transport_class("grpc")
-                    or Transport == type(self).get_transport_class("grpc_asyncio")
-                ),
+                always_use_jwt_access=True,
             )
 
     def list_game_server_clusters(
@@ -367,7 +366,7 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
         request: Union[game_server_clusters.ListGameServerClustersRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListGameServerClustersPager:
@@ -451,7 +450,7 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
         request: Union[game_server_clusters.GetGameServerClusterRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> game_server_clusters.GameServerCluster:
@@ -526,7 +525,7 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
         parent: str = None,
         game_server_cluster: game_server_clusters.GameServerCluster = None,
         game_server_cluster_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -632,7 +631,7 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
             game_server_clusters.PreviewCreateGameServerClusterRequest, dict
         ] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> game_server_clusters.PreviewCreateGameServerClusterResponse:
@@ -692,7 +691,7 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
         ] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -788,7 +787,7 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
             game_server_clusters.PreviewDeleteGameServerClusterRequest, dict
         ] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> game_server_clusters.PreviewDeleteGameServerClusterResponse:
@@ -848,7 +847,7 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
         *,
         game_server_cluster: game_server_clusters.GameServerCluster = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -948,7 +947,7 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
             game_server_clusters.PreviewUpdateGameServerClusterRequest, dict
         ] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> game_server_clusters.PreviewUpdateGameServerClusterResponse:
@@ -1002,6 +1001,19 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
