@@ -113,7 +113,7 @@ class GameServerClustersServiceGrpcTransport(GameServerClustersServiceTransport)
         self._grpc_channel = None
         self._ssl_channel_credentials = ssl_channel_credentials
         self._stubs: Dict[str, Callable] = {}
-        self._operations_client = None
+        self._operations_client: Optional[operations_v1.OperationsClient] = None
 
         if api_mtls_endpoint:
             warnings.warn("api_mtls_endpoint is deprecated", DeprecationWarning)
@@ -484,5 +484,8 @@ class GameServerClustersServiceGrpcTransport(GameServerClustersServiceTransport)
             )
         return self._stubs["preview_update_game_server_cluster"]
 
+    def close(self):
+        self.grpc_channel.close()
+
 
 __all__ = ("GameServerClustersServiceGrpcTransport",)
