@@ -113,7 +113,7 @@ class GameServerConfigsServiceGrpcTransport(GameServerConfigsServiceTransport):
         self._grpc_channel = None
         self._ssl_channel_credentials = ssl_channel_credentials
         self._stubs: Dict[str, Callable] = {}
-        self._operations_client = None
+        self._operations_client: Optional[operations_v1.OperationsClient] = None
 
         if api_mtls_endpoint:
             warnings.warn("api_mtls_endpoint is deprecated", DeprecationWarning)
@@ -364,5 +364,8 @@ class GameServerConfigsServiceGrpcTransport(GameServerConfigsServiceTransport):
             )
         return self._stubs["delete_game_server_config"]
 
+    def close(self):
+        self.grpc_channel.close()
+
 
 __all__ = ("GameServerConfigsServiceGrpcTransport",)
