@@ -19,13 +19,15 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
+from google.api_core.client_options import ClientOptions  # type: ignore
 from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.gaming_v1beta.services.game_server_deployments_service import pagers
@@ -188,10 +190,12 @@ class GameServerDeploymentsServiceAsyncClient:
 
     async def list_game_server_deployments(
         self,
-        request: game_server_deployments.ListGameServerDeploymentsRequest = None,
+        request: Union[
+            game_server_deployments.ListGameServerDeploymentsRequest, dict
+        ] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListGameServerDeploymentsAsyncPager:
@@ -199,7 +203,7 @@ class GameServerDeploymentsServiceAsyncClient:
         location.
 
         Args:
-            request (:class:`google.cloud.gaming_v1beta.types.ListGameServerDeploymentsRequest`):
+            request (Union[google.cloud.gaming_v1beta.types.ListGameServerDeploymentsRequest, dict]):
                 The request object. Request message for
                 GameServerDeploymentsService.ListGameServerDeployments.
             parent (:class:`str`):
@@ -278,17 +282,19 @@ class GameServerDeploymentsServiceAsyncClient:
 
     async def get_game_server_deployment(
         self,
-        request: game_server_deployments.GetGameServerDeploymentRequest = None,
+        request: Union[
+            game_server_deployments.GetGameServerDeploymentRequest, dict
+        ] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> game_server_deployments.GameServerDeployment:
         r"""Gets details of a single game server deployment.
 
         Args:
-            request (:class:`google.cloud.gaming_v1beta.types.GetGameServerDeploymentRequest`):
+            request (Union[google.cloud.gaming_v1beta.types.GetGameServerDeploymentRequest, dict]):
                 The request object. Request message for
                 GameServerDeploymentsService.GetGameServerDeployment.
             name (:class:`str`):
@@ -358,11 +364,13 @@ class GameServerDeploymentsServiceAsyncClient:
 
     async def create_game_server_deployment(
         self,
-        request: game_server_deployments.CreateGameServerDeploymentRequest = None,
+        request: Union[
+            game_server_deployments.CreateGameServerDeploymentRequest, dict
+        ] = None,
         *,
         parent: str = None,
         game_server_deployment: game_server_deployments.GameServerDeployment = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -370,7 +378,7 @@ class GameServerDeploymentsServiceAsyncClient:
         project and location.
 
         Args:
-            request (:class:`google.cloud.gaming_v1beta.types.CreateGameServerDeploymentRequest`):
+            request (Union[google.cloud.gaming_v1beta.types.CreateGameServerDeploymentRequest, dict]):
                 The request object. Request message for
                 GameServerDeploymentsService.CreateGameServerDeployment.
             parent (:class:`str`):
@@ -451,17 +459,19 @@ class GameServerDeploymentsServiceAsyncClient:
 
     async def delete_game_server_deployment(
         self,
-        request: game_server_deployments.DeleteGameServerDeploymentRequest = None,
+        request: Union[
+            game_server_deployments.DeleteGameServerDeploymentRequest, dict
+        ] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single game server deployment.
 
         Args:
-            request (:class:`google.cloud.gaming_v1beta.types.DeleteGameServerDeploymentRequest`):
+            request (Union[google.cloud.gaming_v1beta.types.DeleteGameServerDeploymentRequest, dict]):
                 The request object. Request message for
                 GameServerDeploymentsService.DeleteGameServerDeployment.
             name (:class:`str`):
@@ -545,18 +555,20 @@ class GameServerDeploymentsServiceAsyncClient:
 
     async def update_game_server_deployment(
         self,
-        request: game_server_deployments.UpdateGameServerDeploymentRequest = None,
+        request: Union[
+            game_server_deployments.UpdateGameServerDeploymentRequest, dict
+        ] = None,
         *,
         game_server_deployment: game_server_deployments.GameServerDeployment = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Patches a game server deployment.
 
         Args:
-            request (:class:`google.cloud.gaming_v1beta.types.UpdateGameServerDeploymentRequest`):
+            request (Union[google.cloud.gaming_v1beta.types.UpdateGameServerDeploymentRequest, dict]):
                 The request object. Request message for
                 GameServerDeploymentsService.UpdateGameServerDeployment.
                 Only allows updates for labels.
@@ -644,17 +656,19 @@ class GameServerDeploymentsServiceAsyncClient:
 
     async def get_game_server_deployment_rollout(
         self,
-        request: game_server_deployments.GetGameServerDeploymentRolloutRequest = None,
+        request: Union[
+            game_server_deployments.GetGameServerDeploymentRolloutRequest, dict
+        ] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> game_server_deployments.GameServerDeploymentRollout:
         r"""Gets details a single game server deployment rollout.
 
         Args:
-            request (:class:`google.cloud.gaming_v1beta.types.GetGameServerDeploymentRolloutRequest`):
+            request (Union[google.cloud.gaming_v1beta.types.GetGameServerDeploymentRolloutRequest, dict]):
                 The request object. Request message for
                 GameServerDeploymentsService.GetGameServerDeploymentRollout.
             name (:class:`str`):
@@ -727,11 +741,13 @@ class GameServerDeploymentsServiceAsyncClient:
 
     async def update_game_server_deployment_rollout(
         self,
-        request: game_server_deployments.UpdateGameServerDeploymentRolloutRequest = None,
+        request: Union[
+            game_server_deployments.UpdateGameServerDeploymentRolloutRequest, dict
+        ] = None,
         *,
         rollout: game_server_deployments.GameServerDeploymentRollout = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -744,7 +760,7 @@ class GameServerDeploymentsServiceAsyncClient:
         an error.
 
         Args:
-            request (:class:`google.cloud.gaming_v1beta.types.UpdateGameServerDeploymentRolloutRequest`):
+            request (Union[google.cloud.gaming_v1beta.types.UpdateGameServerDeploymentRolloutRequest, dict]):
                 The request object. Request message for
                 GameServerDeploymentsService.UpdateGameServerRolloutDeployment.
             rollout (:class:`google.cloud.gaming_v1beta.types.GameServerDeploymentRollout`):
@@ -834,9 +850,11 @@ class GameServerDeploymentsServiceAsyncClient:
 
     async def preview_game_server_deployment_rollout(
         self,
-        request: game_server_deployments.PreviewGameServerDeploymentRolloutRequest = None,
+        request: Union[
+            game_server_deployments.PreviewGameServerDeploymentRolloutRequest, dict
+        ] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> game_server_deployments.PreviewGameServerDeploymentRolloutResponse:
@@ -844,7 +862,7 @@ class GameServerDeploymentsServiceAsyncClient:
         does not mutate the rollout resource.
 
         Args:
-            request (:class:`google.cloud.gaming_v1beta.types.PreviewGameServerDeploymentRolloutRequest`):
+            request (Union[google.cloud.gaming_v1beta.types.PreviewGameServerDeploymentRolloutRequest, dict]):
                 The request object. Request message for
                 PreviewGameServerDeploymentRollout.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -899,9 +917,11 @@ class GameServerDeploymentsServiceAsyncClient:
 
     async def fetch_deployment_state(
         self,
-        request: game_server_deployments.FetchDeploymentStateRequest = None,
+        request: Union[
+            game_server_deployments.FetchDeploymentStateRequest, dict
+        ] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> game_server_deployments.FetchDeploymentStateResponse:
@@ -911,7 +931,7 @@ class GameServerDeploymentsServiceAsyncClient:
         older version of the game server deployment.
 
         Args:
-            request (:class:`google.cloud.gaming_v1beta.types.FetchDeploymentStateRequest`):
+            request (Union[google.cloud.gaming_v1beta.types.FetchDeploymentStateRequest, dict]):
                 The request object. Request message for
                 GameServerDeploymentsService.FetchDeploymentState.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -958,6 +978,12 @@ class GameServerDeploymentsServiceAsyncClient:
         # Done; return the response.
         return response
 
+    async def __aenter__(self):
+        return self
+
+    async def __aexit__(self, exc_type, exc, tb):
+        await self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
