@@ -113,7 +113,7 @@ class GameServerDeploymentsServiceGrpcTransport(GameServerDeploymentsServiceTran
         self._grpc_channel = None
         self._ssl_channel_credentials = ssl_channel_credentials
         self._stubs: Dict[str, Callable] = {}
-        self._operations_client = None
+        self._operations_client: Optional[operations_v1.OperationsClient] = None
 
         if api_mtls_endpoint:
             warnings.warn("api_mtls_endpoint is deprecated", DeprecationWarning)
@@ -531,5 +531,8 @@ class GameServerDeploymentsServiceGrpcTransport(GameServerDeploymentsServiceTran
             )
         return self._stubs["fetch_deployment_state"]
 
+    def close(self):
+        self.grpc_channel.close()
+
 
 __all__ = ("GameServerDeploymentsServiceGrpcTransport",)
